# Relative Neighborhood Graph

Compute the Relative Neighborhood Graph from a NumPy distance matrix. 

## Instructions

1. Install:

```
pip install relativeNeighborhoodGraph
```

2. Compute the Relative Neighborhood Graph from a NumPy distance matrix.

```python
from relativeNeighborhoodGraph import returnRNG

RNG = returnRNG(distance_matrix)
```

3. The resulting Relative Neighborhood Graph is returned as a Pandas DataFrame.